@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Dispatcher;
 use vars '$VERSION';
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 use Log::Report 'log-report', syntax => 'SHORT';
 use Log::Report::Util qw/parse_locale expand_reasons %reason_code
@@ -27,6 +27,9 @@ my %predef_dispatchers = map { (uc($_) => __PACKAGE__.'::'.$_) }
 sub new(@)
 {   my ($class, $type, $name, %args) = @_;
 
+use Carp;
+@_%2 or confess "@_";
+
     my $backend
       = $predef_dispatchers{$type}          ? $predef_dispatchers{$type}
       : $type->isa('Log::Dispatch::Output') ? __PACKAGE__.'::LogDispatch'
@@ -151,8 +154,21 @@ sub translate($$$)
       : $msg->toString;
     $text .= "\n";
 
+    if($show_loc)
+    {   if(my $loc = exists $opts->{location} ? $opts->{location}
+                   : [ $self->collectLocation ])
+        {   my ($pkg, $fn, $line, $sub) = @$loc;
+            # pkg and sub are missing when decoded by ::Die
+            $text .= " "
+                  . __x( 'at {filename} line {line}'
+                       , filename => $fn, line => $line)->toString
+                  . "\n";
+        }
+    }
+
     if($show_stack)
-    {   my $stack = $opts->{stack} ||= $self->collectStack;
+    {   my $stack
+          = $opts->{stack} ||= $self->collectStack;
 
         foreach (@$stack)
         {   $text .= $_->[0] . " "
@@ -161,14 +177,6 @@ sub translate($$$)
               . "\n";
         }
     }
-    elsif($show_loc)
-    {   my $loc = $opts->{location} ||= $self->collectLocation;
-        my ($pkg, $fn, $line, $sub) = @$loc;
-        $text .= " "
-              . __x( 'at {filename} line {line}'
-                   , filename => $fn, line => $line)->toString
-              . "\n";
-    }
 
     setlocale(LC_ALL, $oldloc)
         if defined $oldloc;
@@ -181,8 +189,9 @@ sub collectStack($)
 {   my ($self, $max) = @_;
 
     my ($nest, $sub) = (1, undef);
-    $sub = (caller $nest++)[3]
-        while defined $sub && $sub ne 'Log::Report::report';
+    do { $sub = (caller $nest++)[3] }
+    while(defined $sub && $sub ne 'Log::Report::report');
+    defined $sub or $nest = 1;  # not found
 
     # skip syntax==SHORT routine entries
     $nest++ if defined $sub && $sub =~ m/^Log\:\:Report\:\:/;
@@ -205,18 +214,18 @@ sub collectStack($)
 
 
 sub collectLocation()
-{   my $self = shift;
-    my $nest = 1;
+{   my $thing = shift;
+    my $nest  = 1;
     my @args;
 
     do {@args = caller $nest++}
-    until $args[3] eq 'Log::Report::report';  # sub
+    until $args[3] eq 'Log::Report::report';  # common entry point
 
     # skip syntax==SHORT routine entries
     @args = caller $nest++
-        if +(caller $nest)[3] =~ m/^Log\:\:Report\:\:/;
+        if +(caller $nest)[3] =~ m/^Log\:\:Report\:\:[^:]*$/;
 
-    \@args;
+    @args;
 }
 
 
